import { ConfigNotFound, ModuleNameNotProvided } from './errors';
export { ModuleNameNotProvided, ConfigNotFound };
/** Configuration options for Disposition itself. */
export interface Options {
    /**
     * A path to a custom TypeScript configuration file.
     */
    project?: string;
    /**
     * Whether to check for an empty configuration file or not, and
     * report an error if it is.
     */
    checkEmpty?: boolean;
}
/** A configuration file loader. */
export default class Disposition {
    private readonly moduleName;
    /** An array of valid configuration filenames. */
    private readonly filenames;
    /**
     * An object containing configuration options for Dispostion itself.
     */
    private readonly options;
    /**
     * Instantiate a new instance of Disposition.
     *
     * @param moduleName The name that will be used for the
     *                   configuration file.
     * @param options The options object for configuring Dispostion's
     *                behaviour.
     */
    constructor(moduleName: string, options?: Options);
    /**
     * Search for and load the configuation file.
     *
     * The filenames that are searched for are based off
     * the following template: ${moduleName.config.(js|ts|tsx)
     *
     * @param directory The directory to start searching from. Defaults
     *                  to the current working directory.
     */
    load<T>(directory?: string): T;
    /**
     * Search for and load the specified configuration file.
     *
     * @param path The path to the configuration file.
     */
    loadFile<T>(path: string): T;
    /**
     * Require the configuration file and return the required object.
     *
     * @param path The path to the configuration file.
     */
    private require<T>(path);
    /**
     * Check if the provided configuration file is empty, and
     * throw an error if it is.
     */
    private errorOnEmptyConfig<T>(config);
}
